#
# spec file for package kraft
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2007-2011 Klaas Freitag <freitag@kde.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Build without akonadi integration on repositories providing KDE PIM 6 libraries
%if 0%{?suse_version} > 1500 || "%{_repository}" == "KDE_Applications_openSUSE_Leap_15.5" || "%{_repository}" == "KDE_Applications_openSUSE_Leap_15.6"
%define with_akonadi 0
%else
%define with_akonadi 1
%if 0%{?suse_version} == 1500 && 0%{?sle_version} < 150600
%define akonadi_legacy 1
%endif
%endif
%bcond_with qpdfview
Name:           kraft
Version:        1.2.2
Release:        1.1
Summary:        KDE software to manage office documents in the office
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Office/Other
URL:            https://volle-kraft-voraus.de
Source0:        kraft-%{version}.tar.xz
BuildRequires:  extra-cmake-modules
BuildRequires:  libctemplate-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Grantlee5)
BuildRequires:  cmake(KF5Codecs)
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5Contacts)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(Qt5Core) >= 5.5.0
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Sql)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5Xml)
BuildRequires:  pkgconfig(sqlite3)
Requires:       libQt5Sql5-sqlite
Requires:       python3-PyPDF2
Requires:       python3-base
Requires:       python3-reportlab
Requires:       python3-six
Recommends:     python3-Weasyprint
%if %{with qpdfview}
# PATCH-FEATURE-UPSTREAM use_qpdfview.path Open PDFs in qpdfview in appimages
Patch0:         use_qpdfview.patch
%endif
%if %{with_akonadi}
BuildRequires:  cmake(KF5ContactEditor)
%if 0%{?akonadi_legacy}
BuildRequires:  cmake(KF5AkonadiContact)
%else
BuildRequires:  cmake(KPim5AkonadiContact)
%endif
%endif

%description
Kraft is KDE software to help to create and manage office documents such as
offers and invoices in the small enterprise.

It supports easy document creation, templates with calculation, customer management
through the KDE addressbook, highly configurable PDF output and more.

See the website http://volle-kraft-voraus.de for more information.

%prep
%setup -q
%if %{with qpdfview}
%patch -P 0 -p1
%endif

%build

# Create the .tag file that is read by cmake with the version.
# Workaround since the github created tarball does not contain the .tag file with
# the latest commit.

[ -f .tag ] && echo ".tag file exists in tarball." || echo "%{version}" > .tag

%cmake_kf5 -d build %{?akonadi_legacy:-- -DAKONADI_LEGACY_BUILD=ON}

%cmake_build

%install
%kf5_makeinstall -C build
chmod 755 %{buildroot}%{_datadir}/kraft/tools/erml2pdf.py

%if 0%{?suse_version}
%suse_update_desktop_file -G kraft de.volle_kraft_voraus.kraft Office Finance
%endif

%ldconfig_scriptlets

%files
%{_bindir}/kraft
%if %{with_akonadi}
%{_bindir}/findcontact
%endif
%{_datadir}/applications/de.volle_kraft_voraus.kraft.desktop
%{_datadir}/metainfo/de.volle_kraft_voraus.kraft.appdata.xml
%{_datadir}/config.kcfg/*
%{_datadir}/kraft/
%{_datadir}/kxmlgui5/kraft/kraftui.rc
%{_datadir}/kxmlgui5/kraft/katalogview.rc
%{_datadir}/icons/hicolor/scalable/apps/kraft.svg
%lang(de) %{_datadir}/locale/de/LC_MESSAGES/kraft.mo
%lang(nl) %{_datadir}/locale/nl/LC_MESSAGES/kraft.mo

%dir %{_datadir}/config.kcfg
%dir %{_datadir}/kxmlgui5/kraft
%doc AUTHORS README.md INSTALL.md Changes.txt Releasenotes.txt TODO
%license COPYING

%changelog
* Tue Oct  1 2024 Klaas Freitag <opensuse@freisturz.de>
- Update to upstream version 1.2.2
  * Regular service release to fix bugs
  * Fix #242: Do not push item types (Demand) to followup docs
  * Fix #241: Allow negative item sums
  * Changes to fix CI
* Sun May  5 2024 Klaas Freitag <opensuse@freisturz.de>
- Update to upstream version 1.2.1
  * Shipping a fix for a stupid release bug
* Sun May  5 2024 Klaas Freitag <opensuse@freisturz.de>
- Update to upstream version 1.2
  * Manual: Updated text and dutch translations
  * Manual: Updated screenshots for all languages
  * Fix #211: Be more robust if no .git file is there
  * Fix cmake warnings
  * Substancial code cleanups
  * Fix reproducable builds
  * Fix saving of XRechnung files
  * Added a template for XRechnung version 3.0.1
  * Fix #218: Add a image mask for reportlab
  * Fix tests
  * Add checkbox to mark document types to get XRechnung support
  * Add a feedback link to the system overview page
* Mon Mar 11 2024 Christophe Marin <christophe@krop.fr>
- Build without Akonadi integration for repositories that now
  provide the kdepim 6 libraries
* Thu Mar  7 2024 Max Lin <mlin@suse.com>
- Use BuildRequires cmake(KPim5AkonadiContact) on Leap 15.6
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Sat Sep 16 2023 Klaas Freitag <opensuse@freisturz.de>
- Update to version 1.1
  * updated nl translations of the manual
  * update the app translations
  * Fix the application icon
  * Fix the changed Akonadi Prefix, added build switch AKONADI_LEGACY_BUILD
  * More Akonadi related ifdefs
  * Few fixes and improvements to cmake files (eg. #205)
  * cleanup of code and remove endl which removes lots of warnings
  * Allow Macros in pre- and post text, to support date calculations and
    sum calculation (incl. tax) based on tags
  * more tests
  * Add Button to Allow to insert template pre- and post texts rather than
    replace the entire text #167
* Sun Sep 10 2023 Klaas Freitag <opensuse@freisturz.de>
- Update to version 1.1 RC1
- Remove patch fixakonadi.patch because it went upstream
* Sat Apr 29 2023 Klaas Freitag <opensuse@freisturz.de>
- Made the patch of the cmake files a bit more clean
* Fri Apr 28 2023 Klaas Freitag <opensuse@freisturz.de>
- Fix build requirement on AkondiContacts
* Fri Apr 28 2023 Klaas Freitag <opensuse@freisturz.de>
- Add a patch fixakonadi.patch to adopt to latest KDE akonadi.
* Sat Dec 24 2022 Klaas Freitag <opensuse@freisturz.de>
- Update to Kraft version 1.0
  * Have two new merge modes for the watermark tool
  * PDF watermark tool can also append PDF files now
  * Add numbercycle day counter variable (#138)
  * Test improvements and new tests added
  * User manual improvements
  * Localized screenshots in the user manual (Thx Ronald)
  * Demand and Alternative: Do not overwrite custom prefix
  * Default Demand and Alternative text configurable in prefix dialog
  * Add more variables to weasyprint (#166)
  * Ability to add EPC QR code to invoices (Giro Code)
  * Maintain users bank account to be included in documents
  * Add some metadata to the html representation (weasyprint)
  * Use custom icons for all icons in Krafti (#175)
  * Experimental: html tags in pre- and post tags and items & catalogs
  * Add more contrib documents from Achim (BNC)
  * Database refresh only in readonly mode
  * Huge improvements to the AppImage build (#191)
  * Fix: Numbercycle dialog with day counter (#138)
  * Fix: Strikeout for deleted items working again
  * Fix: Delete column in sqlite migrations (#162)
  * Fix: Add -p switch to call of weasyprint (html presentational hints)
  * Fix: Set reconnect option for MySQL (#183)
* Sat Dec  3 2022 Klaas Freitag <opensuse@freisturz.de>
- Update to 1.0 RC1
* Sun May 22 2022 Klaas Freitag <opensuse@freisturz.de>
- Update to upstream version 0.98
- Remove patch Adapt-to-new-Akonadi-includes.patch as it went upstream
* Wed Dec  1 2021 Wolfgang Bauer <wbauer@tmo.at>
- Add Adapt-to-new-Akonadi-includes.patch to fix build with Akonadi
  21.12
* Sun Aug 15 2021 Klaas Freitag <opensuse@freisturz.de>
- Update to upstream version 0.97.
  Version 0.97 is a bugfix release and fixes a few bugs.
- Remove patch keepemptyparts.patch which went upstream.
* Sun Feb 28 2021 Klaas Freitag <opensuse@freisturz.de>
- Add patch keepemptyparts.patch to fix build with older qt versions.
* Sat Feb 27 2021 Klaas Freitag <opensuse@freisturz.de>
- Update to upstream version 0.96
  * Found new MIT licensed icons to avoid uncertainess with CC license.
  * Allow to use the "add new" button in the doc editor to add new
    catalog templates. It presets the correct chapter.
  * Fix: Use the xmlArchivePath correctly (#80)
  * Fix: Handling of Cancel button in template to doc dialog.
  * Fix: Convert newlines in the items to <br> for the weasyprint doc
    generation.
  * Fix: In Followup document: If the standard text for pre and post
    text of the target document type is empty, the one from the
    source document is copied over instead. (#91)
* Fri Aug 28 2020 Klaas Freitag <opensuse@freisturz.de>
- Update to upstream version 0.95
  * New document render engine based on Weasyprint
  * New template library grantlee used
  * User manual added
  * Many other improvements
- Removed patch Check-only-for-Python-3-for-erml2pdf.py.patch
- Removed patch Switch-erml2pdf.py-to-Python-3.patch
* Thu May  7 2020 Wolfgang Bauer <wbauer@tmo.at>
- Add upstream patches to port to Python 3:
  * Check-only-for-Python-3-for-erml2pdf.py.patch
  * Switch-erml2pdf.py-to-Python-3.patch
- Switch python2 package requirements to python3
* Sat Dec 14 2019 Klaas Freitag <opensuse@freisturz.de>
- Update to stable release 0.90
  * Reworked follow up and copy document
  set the correct header- and footer-texts according to the doc type
  Added a checkbox if items should be copied or not
  * New feature: partial invoices that are substracted in the final
  invoice
  * Use an XML based migration system for document types
  * Added the first unit tests to Kraft
  * Made the document templates not containing any language specific
  strings any more. There is only one doc now for all languages,
  set by localized strings as template variables.
  * Removed KeepTogether flag for tables to avoid that a long list
  of items only starts on the next page. Might have impact on
  some docs.
  * Fixed formatting of the amount number in the XML output
  * More Less-KDE: Removed more mandatory dependencies on KDE.
  * Added 'About Kraft' information to Krafts system view.
  * Added document type 'Offer without price tags', which does not
  print price tags on the PDF (issue #58).
  * Internationalization: Added dutch translation
- Removed the patches fix_install_appdata.patch,
  fix_nullptr_warning.patch fix_sql_qt12.patch as those went into
  upstream code.
* Sat Dec  7 2019 Klaas Freitag <opensuse@freisturz.de>
- Update to v0.90 RC 3
- Removed patch rcfixes.patch, went into the release
* Sun Dec  1 2019 Klaas Freitag <opensuse@freisturz.de>
  Update to Kraft v0.90 RC 2:
- Add patch rcfixes.patch that fixes a few glitches in the RC.
- Remove patch fix_install_appdata.patch, gone upstream
- Remove patch fix_sql_qt12.patch, gone upstream
- Remove patch fix_nullptr_warning.patch, gone upstream
* Wed Dec 26 2018 Klaas Freitag <opensuse@freisturz.de>
- Add patch fix_nullptr_warning.patch: Reduce noise when compiling
  by disabling the nullptr initialization warning
- Add patch fix_sql_qt12.patch: Make Kraft build with Qt 5.12 again
* Wed Oct 17 2018 Klaas Freitag <opensuse@freisturz.de>
- Update to v0.82:
  * Fix send document by email
  * Allow emailing through xdg-email and not only through thunderbird
    To enable, set mailUA=xdg in the config file in the system section.
  * Fixed wrong usage of i18n command which caused a lot of error
    messages on the console. (#37)
  * Time calculation: Add a time unit to the form, allow to calculate
    times in hours, minutes and seconds (#43)
  * Refactored the calculation dialog, fixed using margin. (#42)
  * Properly ask to waste changes if user hits cancel in Calc dialog.
  * Fix some glitches in the setup code path, ie. db update.
  * Relaxed the document layout a bit by choosing a smaller font and
    adjusting the table column settings a bit.
  * More minor bug fixes and improvements
* Fri Jun 15 2018 klaas.freitag@suse.com
- Update to v0.81:
  * Fix to build with Qt 5.11
  * CMake fixes: Installation directories
  * Use QProcess instead of system call
  * Fix appstream XML data
  * Fix display of individual tax block on documents
- Add fix_install_appdata.patch: Fixes the installation of appdata.xml
- Add use_qpdfview.patch: Open PDFs in qpdfviewer, used only for
  appimage build in home:kfreitag builds, enabled through OBS prjconf
* Wed Jun 13 2018 klaas.freitag@suse.com
- Update to v0.81rc1
* Wed Jun 13 2018 klaas.freitag@suse.com
- Use conditional build flags to switch on akonadi usage and the
  qpdfviewer. This way, the package is reuseable in a project where
  an appimage is built.
  Added the patch use_qpdfview.patch that is only used for the
  appimage
  Also removed some currently unused Fedora cruft
* Sun Apr  1 2018 klaas.freitag@suse.com
- Update to stable version 0.80, based on Qt5/KF5
  * Port to Qt5/KDE Frameworks 5
  * Reduction of build and runtime dependencies, especially
  of KDE Frameworks, replacing old KDE classes with their
  Qt equivalents
  * Dropped Webkit. Use QTextbrowser instead. Ported html
  generating code and CSS accordingly
  * Dependency on Akonadi is now optional, so builds without
  Akonadi are possible
  * Address management in Kraft was abstracted to work with or
  without Akonadi, other address backends could be implemented
  much easier now
  * Refresh of the GUI plus new icons, easier.
  * Refactored time line models completely
  * Show summaries for month and year items: Amount of doc types
  and added sums for each document type
  * GUI: New filter combo to limit to docs of last week or last
  month
  * Use templates for system view (contributed by Andy Wuest)
  * Ship an AppImage for easy testing of Kraft
  * Updated ReportLab based PDF generation script (erml2pdf)
  * countless bug fixes and improvements
- Removed patch fix_dup_custom_targets.diff, not longer needed.
* Fri Jul  7 2017 fabian@ritter-vogt.de
- Remove kdepim4-runtime requirement, it's not available anymore
  and kraft seems to work fine without it (boo#1047551)
* Thu Dec  8 2016 fabian@ritter-vogt.de
- Revert kde4_runtime_requires change
* Tue Nov 29 2016 olaf@aepfle.de
- Expand macro kde4_runtime_requires only when its available
  to fix quilt setup
* Sat Oct 17 2015 freitag@opensuse.org
- Patch fix_dup_custom_targets.diff added to not add multiple custom
  targets, fixes building Tumbleweed.
* Thu Oct  1 2015 freitag@owncloud.com
  * New upstream version 0.59:
  - Fix discount price calculation: Do not include deleted items.
  - Fix: Mark moved items as modified, to not loose the saving
  - Fix the save loop over items, do delete items seperately
  - Fixes in the setup wizard
  - Enhance data take over when copying documents
  - Fix price calculation with discount items.
  - On doc type change, ask the user if the doc ident is to change.
  - Add GROSSSUM adn NETSUM template variables
  - Memory management fixes
  - Quite some other minor fixes
  * Patch 0001-Fix-Mark-moved-items-as-modified.patch was removed as
  it went to the codebase.
* Fri May  1 2015 freitag@opensuse.org
- Added patch named 0001-Fix-Mark-moved-items-as-modified.patch
  This fixes a bug that item move operations are not saved if the
  move was the only change on a document.
  This patch will be in the next stable release of kraft and can
  be removed from this package.
* Sun Apr  5 2015 freitag@opensuse.org
  * Update to upstream version 0.58:
  - Fix handling of slashes in the doc id template
  - Fix a bug in calculation of the VAT sum
  - Removed kraftcat library as it was unused. Easier building now.
  * Removed patch kraft_no_lib.diff from package as the changes went
  upstream and are contained in the official tarball now.
* Sun Mar 15 2015 freitag@opensuse.org
- Added a patch that does not build a lib from some sources.
  Previous builds contained a libkraftcat which was not used
  publically and also not really tested. rpmlint complained
  so removing is better.
* Sat Feb 28 2015 freitag@opensuse.org
- Fixed license abbreviations and removed INSTALL file to relax
  rpmlint
* Fri Nov  7 2014 freitag@opensuse.org
- New tarball of Kraft 0.57
  Code wise 0.57 is identical to 0.56 as should have been, but
  there have been broken tarballs of 0.56 around, so 0.57 was
  tagged to be on the save side.
* Tue Nov  4 2014 freitag@owncloud.com
  * New upstream release 0.56
  - Fix handling of custom greetings in combobox.
  - Handle document type changes correctly: Set a new ident number
  depending on the new document id
  - Fix behaviour of the greeting combobox: Do not loose custom entries
  any more
  - Add receipient email address if document is emailed
  - Fix document emailing for thunderbird
  - Fix removing of alternative- and on-demand state of items
  - Wording fixes
  - Fix Ok/Cancel for doc editor
  - Better error messages if template can not be read
  - A couple of crash fixes and memory management cleanups
* Thu May 29 2014 freitag@owncloud.com
  * New upstream release 0.55
  - Fix a bug with the PDF generation, regression in 0.54
  - Fix compiling with latest version of ctemplate
* Sun May 11 2014 freitag@opensuse.org
  * New upstream release 0.54
  - Use new address fetch job implementation that works independant
    from Nepomuk- or Baloo indexing of contacts. (KDE >= 4.12)
  - Support note-of-delivery documents (Lieferscheine) without prices.
  - Added findcontact utility
  - Generate a customer sorted document storage structure on disk
  - Improve stylesheet handling in templates, introduce CSS_IMG_PATH
  - Use environment variable KRAFT_HOME more consquentely
  - Fix tax sum calculation
  - Add customer address UID variable to number circle tags
  - Some memleak fixes
  - Add "followup document" to main menu
  - Fix installation of identity.trml
  - Allow the tags USERNAME, DATE and TIME in item templates.
  - Lots of other cleanups and fixes
* Fri Oct 11 2013 freitag@owncloud.com
  * Upstream release 0.53
  - Fix screwed tarball 0.51
  - Fixes drag and drop handling in catalog window.
  - Fixes with units, do not confuse units any more
  - Utf8 fixes
  - other minor fixes
* Sun Sep 22 2013 freitag@owncloud.com
  * New upstream release 0.51
  - Fix drag and drop in catalogues.
  - Implemented removal of sub chapters.
  - Add the content of an entire template catalog chapter to the document
    if the chapter item is selected.
  - Added a new setting "Own Identity" to allow to pick the own identity
    from the address books in an installed system.
  - Make text template loading utf8 save.
  - Reworked image-in-template example in invoice report template.
  - Fixed unit handling, no more startsWith coparison of text.
* Mon Mar 11 2013 freitag@owncloud.com
- Added a patch to fix catalog editing of the material catalog.
  With that patch, templates and sub chapters can be moved around
  using drag and drop and the changes are actually saved.
* Mon Dec 17 2012 freitag@opensuse.org
  * update to Kraft version 0.50
- Handling of individual tax rates for each document item
- bugfix: escape texts in reports correctly (reported by Lars Diel).
- bugfix: if akonadi address was not found, display proper msg.
- Proper error message if a python module is not installed but needed
  by the pdf generator.
- added button to assign an address book entry as document receiver
  for existing documents (Bug #3477467)
- bugfix: Display of number of processed sql commands in setup
  assistant (Bug #3560611)
- started to optimize database save of documents for more performant
  saves.
- bugfix: Fixed import of document items from csv lists.
- added page number on default document from page two to end.
- bugfix: Fixed mysql database setup.
- Rearragned doc type setup dialog to better display path names of
  template file and watermark file.
- bugfix: If a manual entered template has checkbox "store in template
  catalog, the template is immediately written to and catalog is
  reloaded.
- bugfix: Focus on the last added item on document edit.
* Tue Nov 29 2011 freitag@suse.com
- added patch to fix the own identity search in portal.cpp
* Fri Nov 11 2011 freitag@suse.com
- added patch to make follow-up documents and copy doc work
  again.
* Tue Nov  8 2011 freitag@suse.com
- update to upstream version 0.45
  0.45 was released as a fix for 0.44 which contains a bug in showing
  decimal places of items on the PDF document. Needs quick fix.
* Thu Nov  3 2011 freitag@suse.com
- update to upstream tarball 0.44
- Completely reworked the addressbook widget in Kraft, used in new doc
  assistant and in the "who am i" dialog: Fully Akonadi-based, works
  with various addressbooks and loads addresses way more fast.
- Completely reworked text template widget used in the document editor:
  Less bugs, more obvious gui, help texts where needed
- Fixed bug that crashed Kraft when clicking on empty catalog chapters.
- Add ability to add localized report template files, added german
  localization
- Fixed bug that numbers in the doc are not localized correctly
- Fixed bug that the doc type is not taken correctly from the new doc
  wizard
- No need any more to checkbox single item templates to move them into
  the document. Selecting is sufficient.
- Added a search line in the "who am i"-dialog
- even more bugfixes
* Wed May 25 2011 freitag@novell.com
- update to upstream tarball 0.43
* Thu Apr 14 2011 freitag@novell.com
- update to upstream tarball 0.41, incl. patch for non rpath lib dir
* Mon Mar 21 2011 freitag@novell.com
- fix for address selection (name -> realname)
- removed deb build files
* Tue Apr 13 2010 freitag@novell.com
- update to the final 0.40 tarball - harrah!
* Wed Apr  7 2010 freitag@novell.com
- update to third beta version for the 0.40 release
